@@ -2,7 +2,7 @@
 
 __author__ = """François Durand"""
 __email__ = 'fradurand@gmail.com'
-__version__ = '0.3.0'
+__version__ = '0.4.0'
 
 
 # Utils
@@ -30,10 +30,12 @@ from svvamp.preferences.generator_profile_vmf_hypersphere import GeneratorProfil
 from svvamp.rules.rule import Rule
 from svvamp.rules.rule_approval import RuleApproval
 from svvamp.rules.rule_baldwin import RuleBaldwin
+from svvamp.rules.rule_black import RuleBlack
 from svvamp.rules.rule_borda import RuleBorda
 from svvamp.rules.rule_bucklin import RuleBucklin
 from svvamp.rules.rule_condorcet_sum_defeats import RuleCondorcetSumDefeats
 from svvamp.rules.rule_coombs import RuleCoombs
+from svvamp.rules.rule_copeland import RuleCopeland
 from svvamp.rules.rule_icrv import RuleICRV
 from svvamp.rules.rule_irv_average import RuleIRVAverage
 from svvamp.rules.rule_irv_duels import RuleIRVDuels
@@ -48,6 +50,8 @@ from svvamp.rules.rule_range_voting import RuleRangeVoting
 from svvamp.rules.rule_ranked_pairs import RuleRankedPairs
 from svvamp.rules.rule_schulze import RuleSchulze
 from svvamp.rules.rule_smith_irv import RuleSmithIRV
+from svvamp.rules.rule_split_cycle import RuleSplitCycle
+from svvamp.rules.rule_star import RuleSTAR
 from svvamp.rules.rule_tideman import RuleTideman
 from svvamp.rules.rule_two_round import RuleTwoRound
 from svvamp.rules.rule_veto import RuleVeto
